@@ -5,6 +5,7 @@ from matplotlib import pyplot as plt
 from poisson_approval.constants.constants import *
 from poisson_approval.strategies.StrategyThreshold import StrategyThreshold
 from poisson_approval.profiles.ProfileCardinalContinuous import ProfileCardinalContinuous
+from poisson_approval.utils.DictPrintingInOrder import DictPrintingInOrder
 from poisson_approval.utils.DictPrintingInOrderIgnoringZeros import DictPrintingInOrderIgnoringZeros
 from poisson_approval.utils.Util import my_division, product_dict
 from poisson_approval.utils.UtilPreferences import sort_weak_order, is_weak_order, is_hater
@@ -410,7 +411,7 @@ d_weak_order_share={'a~c>b': Fraction(3, 10)})
 
     @cached_property
     def d_candidate_welfare(self):
-        d = {candidate: 0 for candidate in CANDIDATES}
+        d = DictPrintingInOrder({candidate: 0 for candidate in CANDIDATES})
         for ranking, histogram in self.d_ranking_histogram.items():
             share_ranking = self.d_ranking_share[ranking]
             d[ranking[0]] += share_ranking
